==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/HinemosAgentCore/src/com/clustercontrol/hinemosagent/action/GetAgentListTableDefine.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.hinemosagent.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Locale;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.hinemosagent.ejb.session.MonitorAgentController;
import com.clustercontrol.hinemosagent.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * Hinemos Agentƻơ֥륯饹Ǥ
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetAgentListTableDefine {

    /**
     * Hinemos AgentƻΥơ֥֤ޤ
     * 
     * @return Hinemos Agentƻơ֥
     */
    public static ArrayList get() {
    	
    	MonitorAgentController agent = EjbConnectionManager.getConnectionManager().getAgentController();

        ArrayList tableDefine = null;
        
        try {
			tableDefine = agent.getAgentListTableDefine(Locale.getDefault());
		} catch (RemoteException e) {
			if(e instanceof AccessException){
				// ʤξ硢顼ɽ
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
		}

        return tableDefine;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/HinemosAgentCore/src/com/clustercontrol/hinemosagent/action/GetAgentListTableDefine.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.hinemosagent.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Locale;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.hinemosagent.ejb.session.MonitorAgentController;
import com.clustercontrol.hinemosagent.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * Hinemos Agent監視一覧テーブル定義情報を取得するクラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetAgentListTableDefine {

    /**
     * Hinemos Agent監視一覧のテーブル定義情報を返します。
     * 
     * @return Hinemos Agent監視一覧テーブル定義情報
     */
    public static ArrayList get() {
    	
    	MonitorAgentController agent = EjbConnectionManager.getConnectionManager().getAgentController();

        ArrayList tableDefine = null;
        
        try {
			tableDefine = agent.getAgentListTableDefine(Locale.getDefault());
		} catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
		}

        return tableDefine;
    }
}
